@@ -9,3 +9,8 @@ haven::is.labelled
 #' @importFrom haven labelled_spss
 #' @export
 haven::labelled_spss
+
+
+#' @importFrom dplyr `%>%`
+#' @export
+dplyr::`%>%`
