@@ -109,7 +109,7 @@ var_label.data.frame <- function(x, unlist = FALSE) {
 #' @examples
 #' if (require(dplyr)) {
 #'   # adding some variable labels
-#'   df <- data_frame(s1 = c("M", "M", "F"), s2 = c(1, 1, 2)) %>%
+#'   df <- tibble(s1 = c("M", "M", "F"), s2 = c(1, 1, 2)) %>%
 #'     set_variable_labels(s1 = "Sex", s2 = "Yes or No?")
 #'   var_label(df)
 #'
@@ -129,7 +129,7 @@ set_variable_labels <- function(.data, ..., .labels = NA) {
   if (!identical(.labels, NA)) {
     var_label(.data) <- .labels
   }
-  values <- list(...)
+  values <- rlang::dots_list(...)
   if (length(values) > 0) {
     if (!all(names(values) %in% names(.data)))
       stop("some variables not found in .data")
